import json
from naxai.models.voice.responses.broadcasts_responses import GetBroadcastInputMetricsResponse

class InputResource:
    """
    This class provides methods to interact with the Voice Broadcast Metrics Input resource in the API.

    """
    def __init__(self, client, root_path):
        self._client = client
        self.root_path = root_path
        self.headers = {"Content-Type": "application/json"}

    async def get(self, broadcast_id: str):
        """
        Get the inputs for a voice broadcast by id.
        https://docs.naxai.com/reference/voicebroadcastmetricsinputgetbyid

        Args:
            broadcast_id (str): The unique identifier of the broadcast to get the inputs.
            
        Returns:
            GetBroadcastInputMetricsResponse: A Pydantic model containing the input counts for the given broadcast.
                The model includes counts for each DTMF key (0-9, *, #) and a total count.
                
        Example:
            >>> input_result = await client.voice.broadcasts.metrics.inputs.get(
            ...     broadcast_id="XXXXXXXXX"
            ... )
            >>> print(f"Total inputs received: {input_result.total}")
            >>> print(f"Option 1 selected: {input_result.input_1} times")
        """

        return GetBroadcastInputMetricsResponse.model_validate_json(json.dumps(await self._client._request("GET", self.root_path + "/" + broadcast_id + "/metrics/input", headers=self.headers)))